<?php

declare(strict_types=1);

namespace Drupal\page_layouts\Plugin\Layouts;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\file\Entity\File;
use Drupal\page_layouts\LayoutsPluginBase;

/**
 * Plugin implementation of the layouts.
 *
 * @Layouts(
 *   id = "layouts_text_left_image_right",
 *   label = @Translation("Text Left Image Right"),
 *   description = @Translation("Text on the left image on the right each taking up half the space.")
 * )
 */
final class TextLeftImageRight extends LayoutsPluginBase {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getLayout($result) {

    $file = File::load($result->image_1->target_id);

    $image_1['preview'] = [
      '#theme' => 'image_style',
      '#style_name' => 'large',
      '#uri' => $file->uri->value,
      '#alt' => $result->image_1->alt,
    ];

    $build['layout'] = [
      '#theme' => 'layouts_text_left_image_right',
      '#content' => [
        'content_1' => $result->content_1->value,
        'image_1' => $image_1,
      ],
    ];

    return \Drupal::service('renderer')->render($build);
  }

}
